@@ -1007,13 +1007,23 @@ def cmdprune(ui, repo, *revs, **opts):
                     # changed
                     changedfiles.extend(repo[rev].files())
 
+                need_write = True
+                if util.safehasattr(repo.dirstate, 'changing_parents'):
+                    changing_parents = repo.dirstate.changing_parents(repo)
+                else:
+                    # hg <= 6.3 (7a8bfc05b691)
+                    need_write = False
+                    changing_parents = util.nullcontextmanager()
+
                 # reset files that only changed in the dirstate too
                 dirstate = repo.dirstate
                 dirchanges = compat.dirchanges(dirstate)
                 changedfiles.extend(dirchanges)
-                repo.dirstate.rebuild(newnode.node(), newnode.manifest(),
-                                      changedfiles)
-                dirstate.write(tr)
+                with changing_parents:
+                    repo.dirstate.rebuild(newnode.node(), newnode.manifest(),
+                                          changedfiles)
+                if need_write:
+                    dirstate.write(tr)
             else:
                 bookactive = repo._activebookmark
                 # Active bookmark that we don't want to delete (with -B option)
@@ -1143,7 +1153,7 @@ def cmdsplit(ui, repo, *pats, **opts):
 
         # Set the right branch
         # XXX-TODO: Find a way to set the branch without altering the dirstate
-        repo.dirstate.setbranch(ctx.branch())
+        compat.setbranch(repo, ctx.branch())
 
         if pats:
             # refresh the wctx used for the matcher
@@ -1242,7 +1252,7 @@ def cmdsplit(ui, repo, *pats, **opts):
         tr.close()
     finally:
         # Restore the old branch
-        repo.dirstate.setbranch(savedbranch)
+        compat.setbranch(repo, savedbranch)
 
         lockmod.release(tr, lock, wlock)
 
@@ -1411,7 +1421,7 @@ def _dopick(ui, repo, pickstate, origctx):
         newnode = repo.commit(text=origctx.description(),
                               user=origctx.user(),
                               date=origctx.date(), extra=origctx.extra())
-    repo.dirstate.setbranch(origctx.branch())
+    compat.setbranch(repo, origctx.branch())
 
     if pickstate:
         pickstate.delete()
