@@ -529,6 +529,15 @@ if not markdirtyfixed:
 
     context.overlayworkingctx._markdirty = fixedmarkdirty
 
+def setbranch(repo, branch):
+    # this attribute was introduced at about the same time dirstate.setbranch()
+    # was modified
+    # hg <= 6.3 (e9379b55ed80)
+    if util.safehasattr(dirstate, 'requires_changing_files_or_status'):
+        repo.dirstate.setbranch(branch, repo.currenttransaction())
+    else:
+        repo.dirstate.setbranch(branch)
+
 if util.safehasattr(dirstate.dirstate, 'get_entry'):
     def dirchanges(dirstate):
         return [
