@@ -791,7 +791,7 @@ def mergebranches(repo, divergent, other, base):
             # preserved
             pass
         elif basebranch == divbranch and basebranch != othbranch:
-            repo.dirstate.setbranch(othbranch)
+            compat.setbranch(repo, othbranch)
         else:
             # all the three branches are different
             index = repo.ui.promptchoice(_(b"content divergent changesets on "
@@ -802,11 +802,11 @@ def mergebranches(repo, divergent, other, base):
                                          (basebranch, divbranch, othbranch), 0)
 
             if index == 0:
-                repo.dirstate.setbranch(basebranch)
+                compat.setbranch(repo, basebranch)
             elif index == 1:
                 pass
             elif index == 2:
-                repo.dirstate.setbranch(othbranch)
+                compat.setbranch(repo, othbranch)
 
 def mergecommitmessages(ui, basedesc, divdesc, othdesc):
     """merges the commit messages and return the new merged message and whether
@@ -999,7 +999,7 @@ def _relocatecommitondisk(repo, orig, dest, pctx, keepbranch, commitmsg, extra):
     if repo[b'.'].rev() != dest.rev():
         compat._update(repo, dest, branchmerge=False, force=True)
     if keepbranch:
-        repo.dirstate.setbranch(orig.branch())
+        compat.setbranch(repo, orig.branch())
     if util.safehasattr(repo, 'currenttopic'):
         # uurrgs
         # there no other topic setter yet
